@@ -23,5 +23,5 @@ with open("/etc/passwd", "rb") as f:  # , buffering=0)
         seek = (end - between) / COUNT * 1e9
         read = both - seek
         print(
-            f"{both:.2f} ns/(seek+read), {seek:.2f} ns/seek, estimate ~{read:.2f} ns/read"
+            f"{both:.2f} ns/(seek+read), {seek:.2f} ns/seek, estimate ~{read:.2f} ns/read",
         )
