@@ -11,11 +11,12 @@ if os.name == "nt":
         """
         void* WINAPI GetProcAddress(void* hModule, char* lpProcName);
         typedef void (*PyOS_sighandler_t)(int);
-    """
+    """,
     )
     kernel32 = ffi.dlopen("kernel32.dll")
     PyOS_getsig_ptr = kernel32.GetProcAddress(
-        ffi.cast("void*", sys.dllhandle), b"PyOS_getsig"
+        ffi.cast("void*", sys.dllhandle),
+        b"PyOS_getsig",
     )
     PyOS_getsig = ffi.cast("PyOS_sighandler_t (*)(int)", PyOS_getsig_ptr)
 
