@@ -29,16 +29,16 @@
 import errno
 import socket
 
-import attr
+import attrs
 
 
-@attr.s(repr=False)
+@attrs.define(repr=False, slots=False)
 class Options:
-    listen1_early = attr.ib(default=None)
-    listen1_middle = attr.ib(default=None)
-    listen1_late = attr.ib(default=None)
-    server = attr.ib(default=None)
-    listen2 = attr.ib(default=None)
+    listen1_early = None
+    listen1_middle = None
+    listen1_late = None
+    server = None
+    listen2 = None
 
     def set(self, which, sock):
         value = getattr(self, which)
@@ -47,7 +47,7 @@ class Options:
 
     def describe(self):
         info = []
-        for f in attr.fields(self.__class__):
+        for f in attrs.fields(self.__class__):
             value = getattr(self, f.name)
             if value is not None:
                 info.append(f"{f.name}={value}")
