@@ -94,17 +94,17 @@ class Trace(trio.abc.Instrument):
         except RuntimeError:
             pass
         else:
-            id = next(self.ids)
+            id_ = next(self.ids)
             self._write(
                 ph="s",
                 cat="wakeup",
-                id=id,
+                id=id_,
                 tid=waker._counter,
             )
             self._write(
                 cat="wakeup",
                 ph="f",
-                id=id,
+                id=id_,
                 tid=task._counter,
             )
 
